#
# spec file for package cabal-plan
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name cabal-plan
Name:           %{pkg_name}
Version:        0.7.2.1
Release:        bp155.2.14
Summary:        Library and utility for processing cabal's plan.json file
License:        GPL-2.0-or-later
URL:            https://hackage.haskell.org/package/%{name}
Source0:        https://hackage.haskell.org/package/%{name}-%{version}/%{name}-%{version}.tar.gz
Source1:        https://hackage.haskell.org/package/%{name}-%{version}/revision/1.cabal#/%{name}.cabal
BuildRequires:  chrpath
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-aeson-devel
BuildRequires:  ghc-ansi-terminal-devel
BuildRequires:  ghc-async-devel
BuildRequires:  ghc-base-compat-devel
BuildRequires:  ghc-base16-bytestring-devel
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-containers-devel
BuildRequires:  ghc-directory-devel
BuildRequires:  ghc-filepath-devel
BuildRequires:  ghc-mtl-devel
BuildRequires:  ghc-optics-core-devel
BuildRequires:  ghc-optparse-applicative-devel
BuildRequires:  ghc-parsec-devel
BuildRequires:  ghc-process-devel
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-semialign-devel
BuildRequires:  ghc-singleton-bool-devel
BuildRequires:  ghc-text-devel
BuildRequires:  ghc-these-devel
BuildRequires:  ghc-topograph-devel
BuildRequires:  ghc-transformers-devel
BuildRequires:  ghc-vector-devel
ExcludeArch:    %{ix86}

%description
This package provides a library (see "Cabal.Plan") for decoding 'plan.json'
files as well as the simple tool 'cabal-plan' for extracting and pretty
printing the information contained in the 'plan.json' file.

'plan.json' files are generated by
[cabal](https://hackage.haskell.org/package/cabal-install)'s [Nix-style local
builds](http://cabal.readthedocs.io/en/latest/nix-local-build.html) and contain
detailed information about the build/install plan computed by the cabal solver.

== 'cabal-plan' utility

The 'cabal-plan' executable (enabled via the 'exe' cabal flag) provides various
operations:

[info] Show basic report of dependency tree [show] Dump 'PlanJson'
data-structure via 'Show' instance [tred] Show dependency tree as a graph
[diff] Diff two install plans [list-bins] List all binaries [list-bin] List
single binary (useful for scripting, e.g. 'cabal list-bin exe:cabal-plan')
[fingerprint] Print SHA256 sums of dependencies' source tarballs and cabal
files [dot] Generate graph of dependencies in '.dot' format [topo] Print plan
topologically sorted [license-report] Generate license report for a component
(only available when built with 'license-report' flag enabled); see
<src/example/cabal-plan.md report example for cabal-plan>
(<src/example/cabal-plan.html Pandoc rendered HTML>)

See also ["New things in Haskell package QA"
Blogpost](http://oleg.fi/gists/posts/2018-01-08-haskell-package-qa.html) for a
description of the 'topo' and 'dot' operations as well as how to enable
tab-completion.

%package -n ghc-%{name}
Summary:        Haskell %{name} library

%description -n ghc-%{name}
This package provides the Haskell %{name} shared library.

%package -n ghc-%{name}-devel
Summary:        Haskell %{name} library development files
Requires:       ghc-%{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description -n ghc-%{name}-devel
This package provides the Haskell %{name} library development files.

%prep
%autosetup
cp -p %{SOURCE1} %{name}.cabal
cabal-tweak-dep-ver optparse-applicative '^>= 0.16.0.0' '< 1'

%build
%define cabal_configure_options -fexe
%ghc_lib_build

%install
%ghc_lib_install
%ghc_fix_rpath %{pkg_name}-%{version}

%post -n ghc-%{name}-devel
%ghc_pkg_recache

%postun -n ghc-%{name}-devel
%ghc_pkg_recache

%files
%license LICENSE.GPLv2
%license LICENSE.GPLv3
%doc ChangeLog.md example
%{_bindir}/%{name}

%files -n ghc-%{name} -f ghc-%{name}.files
%license LICENSE.GPLv2
%license LICENSE.GPLv3

%files -n ghc-%{name}-devel -f ghc-%{name}-devel.files
%doc ChangeLog.md example

%changelog
* Wed Jan  5 2022 Peter Simons <psimons@suse.com>
- Update cabal-plan to version 0.7.2.1 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Sun Oct 10 2021 psimons@suse.com
- Update cabal-plan to version 0.7.2.1.
  [#]# 0.7.2.1
  * Support Cabal-3.6
  * Support aeson-2.0.0.0
  * Drop support for GHC prior 8.2
* Fri Sep 10 2021 Ondřej Súkup <mimi.vx@gmail.com>
- relax overconstrained deps on base-compat
* Tue Mar  9 2021 Ondřej Súkup <mimi.vx@gmail.com>
- relax overconstrained deps
* Thu Dec 17 2020 Ondřej Súkup <mimi.vx@gmail.com>
- disable %%{ix86} build
* Mon Oct 19 2020 psimons@suse.com
- Update cabal-plan to version 0.7.2.0.
  Upstream has edited the change log file since the last release in
  a non-trivial way, i.e. they did more than just add a new entry
  at the top. You can review the file at:
  http://hackage.haskell.org/package/cabal-plan-0.7.2.0/src/ChangeLog.md
* Wed Sep  9 2020 psimons@suse.com
- Update cabal-plan to version 0.7.1.0.
  Upstream has edited the change log file since the last release in
  a non-trivial way, i.e. they did more than just add a new entry
  at the top. You can review the file at:
  http://hackage.haskell.org/package/cabal-plan-0.7.1.0/src/ChangeLog.md
* Mon Aug 31 2020 psimons@suse.com
- Update cabal-plan to version 0.7.0.0 revision 2.
  Upstream has revised the Cabal build instructions on Hackage.
* Wed Aug 26 2020 psimons@suse.com
- Add cabal-plan at version 0.7.0.0.
